pub fn check_source(creds: &SourceCredentials) -> Result<(), MissingCredential>Expand description
Check whether a source has all required credentials configured.
pub fn check_source(creds: &SourceCredentials) -> Result<(), MissingCredential>Check whether a source has all required credentials configured.